Class: TelvriSecurity::CheckSimSwapDto
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TelvriSecurity::CheckSimSwapDto
- Defined in:
- lib/telvri_security/models/check_sim_swap_dto.rb
Instance Attribute Summary collapse
-
#max_age_hours ⇒ Object
Maximum acceptable age, in hours, for SIM-swap intelligence.
-
#phone_number ⇒ Object
Subscriber phone number in strict E.164 format.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckSimSwapDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CheckSimSwapDto
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TelvriSecurity::CheckSimSwapDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TelvriSecurity::CheckSimSwapDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] else self.phone_number = nil end if attributes.key?(:'max_age_hours') self.max_age_hours = attributes[:'max_age_hours'] else self.max_age_hours = 24 end end |
Instance Attribute Details
#max_age_hours ⇒ Object
Maximum acceptable age, in hours, for SIM-swap intelligence.
22 23 24 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 22 def max_age_hours @max_age_hours end |
#phone_number ⇒ Object
Subscriber phone number in strict E.164 format. Supports global numbering plans (e.g. +1 US, +49 DE, +234 NG Airtel/MTN).
19 20 21 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 19 def phone_number @phone_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 25 def self.attribute_map { :'phone_number' => :'phoneNumber', :'max_age_hours' => :'maxAgeHours' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 51 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 43 def self.openapi_types { :'phone_number' => :'String', :'max_age_hours' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
156 157 158 159 160 161 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 156 def ==(o) return true if self.equal?(o) self.class == o.class && phone_number == o.phone_number && max_age_hours == o.max_age_hours end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 171 def hash [phone_number, max_age_hours].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 87 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @phone_number.nil? invalid_properties.push('invalid value for "phone_number", phone_number cannot be nil.') end pattern = Regexp.new(/^\+[1-9]\d{1,14}$/) if @phone_number !~ pattern invalid_properties.push("invalid value for \"phone_number\", must conform to the pattern #{pattern}.") end if !@max_age_hours.nil? && @max_age_hours > 168 invalid_properties.push('invalid value for "max_age_hours", must be smaller than or equal to 168.') end if !@max_age_hours.nil? && @max_age_hours < 1 invalid_properties.push('invalid value for "max_age_hours", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 117 118 119 |
# File 'lib/telvri_security/models/check_sim_swap_dto.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @phone_number.nil? return false if @phone_number !~ Regexp.new(/^\+[1-9]\d{1,14}$/) return false if !@max_age_hours.nil? && @max_age_hours > 168 return false if !@max_age_hours.nil? && @max_age_hours < 1 true end |