Class: TelvriSecurity::DeveloperAuthApi

Inherits:
Object
  • Object
show all
Defined in:
lib/telvri_security/api/developer_auth_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ DeveloperAuthApi

Returns a new instance of DeveloperAuthApi.



19
20
21
# File 'lib/telvri_security/api/developer_auth_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/telvri_security/api/developer_auth_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#auth_controller_login(email, password, opts = {}) ⇒ nil

Authenticate a developer account Accepts login credentials and redirects to the dashboard on success.

Parameters:

  • email (String)

    Developer account email address.

  • password (String)

    Account password.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


28
29
30
31
# File 'lib/telvri_security/api/developer_auth_api.rb', line 28

def (email, password, opts = {})
  (email, password, opts)
  nil
end

#auth_controller_login_with_http_info(email, password, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Authenticate a developer account Accepts login credentials and redirects to the dashboard on success.

Parameters:

  • email (String)

    Developer account email address.

  • password (String)

    Account password.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/telvri_security/api/developer_auth_api.rb', line 39

def (email, password, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DeveloperAuthApi.auth_controller_login ...'
  end
  # verify the required parameter 'email' is set
  if @api_client.config.client_side_validation && email.nil?
    fail ArgumentError, "Missing the required parameter 'email' when calling DeveloperAuthApi.auth_controller_login"
  end
  # verify the required parameter 'password' is set
  if @api_client.config.client_side_validation && password.nil?
    fail ArgumentError, "Missing the required parameter 'password' when calling DeveloperAuthApi.auth_controller_login"
  end
  if @api_client.config.client_side_validation && password.to_s.length < 8
    fail ArgumentError, 'invalid value for "password" when calling DeveloperAuthApi.auth_controller_login, the character length must be greater than or equal to 8.'
  end

  # resource path
  local_var_path = '/auth/login'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded', 'application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['email'] = email
  form_params['password'] = password

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"DeveloperAuthApi.auth_controller_login",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DeveloperAuthApi#auth_controller_login\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#auth_controller_logout(opts = {}) ⇒ nil

Sign out of the developer dashboard

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


103
104
105
106
# File 'lib/telvri_security/api/developer_auth_api.rb', line 103

def auth_controller_logout(opts = {})
  auth_controller_logout_with_http_info(opts)
  nil
end

#auth_controller_logout_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>

Sign out of the developer dashboard

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/telvri_security/api/developer_auth_api.rb', line 111

def auth_controller_logout_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DeveloperAuthApi.auth_controller_logout ...'
  end
  # resource path
  local_var_path = '/auth/logout'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"DeveloperAuthApi.auth_controller_logout",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DeveloperAuthApi#auth_controller_logout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#auth_controller_signup(full_name, email, password, confirm_password, opts = {}) ⇒ nil

Create a developer account Registers a developer account and redirects to the dashboard on success.

Parameters:

  • full_name (String)

    Full name for the developer account.

  • email (String)

    Work email used for dashboard access and API key delivery.

  • password (String)

    Account password.

  • confirm_password (String)

    Password confirmation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :company (String)

    Company or team name.

Returns:

  • (nil)


162
163
164
165
# File 'lib/telvri_security/api/developer_auth_api.rb', line 162

def (full_name, email, password, confirm_password, opts = {})
  (full_name, email, password, confirm_password, opts)
  nil
end

#auth_controller_signup_with_http_info(full_name, email, password, confirm_password, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Create a developer account Registers a developer account and redirects to the dashboard on success.

Parameters:

  • full_name (String)

    Full name for the developer account.

  • email (String)

    Work email used for dashboard access and API key delivery.

  • password (String)

    Account password.

  • confirm_password (String)

    Password confirmation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :company (String)

    Company or team name.

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/telvri_security/api/developer_auth_api.rb', line 176

def (full_name, email, password, confirm_password, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: DeveloperAuthApi.auth_controller_signup ...'
  end
  # verify the required parameter 'full_name' is set
  if @api_client.config.client_side_validation && full_name.nil?
    fail ArgumentError, "Missing the required parameter 'full_name' when calling DeveloperAuthApi.auth_controller_signup"
  end
  # verify the required parameter 'email' is set
  if @api_client.config.client_side_validation && email.nil?
    fail ArgumentError, "Missing the required parameter 'email' when calling DeveloperAuthApi.auth_controller_signup"
  end
  # verify the required parameter 'password' is set
  if @api_client.config.client_side_validation && password.nil?
    fail ArgumentError, "Missing the required parameter 'password' when calling DeveloperAuthApi.auth_controller_signup"
  end
  if @api_client.config.client_side_validation && password.to_s.length < 8
    fail ArgumentError, 'invalid value for "password" when calling DeveloperAuthApi.auth_controller_signup, the character length must be greater than or equal to 8.'
  end

  # verify the required parameter 'confirm_password' is set
  if @api_client.config.client_side_validation && confirm_password.nil?
    fail ArgumentError, "Missing the required parameter 'confirm_password' when calling DeveloperAuthApi.auth_controller_signup"
  end
  if @api_client.config.client_side_validation && confirm_password.to_s.length < 8
    fail ArgumentError, 'invalid value for "confirm_password" when calling DeveloperAuthApi.auth_controller_signup, the character length must be greater than or equal to 8.'
  end

  # resource path
  local_var_path = '/auth/signup'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/x-www-form-urlencoded', 'application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}
  form_params['fullName'] = full_name
  form_params['email'] = email
  form_params['password'] = password
  form_params['confirmPassword'] = confirm_password
  form_params['company'] = opts[:'company'] if !opts[:'company'].nil?

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"DeveloperAuthApi.auth_controller_signup",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: DeveloperAuthApi#auth_controller_signup\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end