Class: TelvriSecurity::SignupDto
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TelvriSecurity::SignupDto
- Defined in:
- lib/telvri_security/models/signup_dto.rb
Instance Attribute Summary collapse
-
#company ⇒ Object
Company or team name.
-
#confirm_password ⇒ Object
Password confirmation.
-
#email ⇒ Object
Work email used for dashboard access and API key delivery.
-
#full_name ⇒ Object
Full name for the developer account.
-
#password ⇒ Object
Account password.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SignupDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SignupDto
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/telvri_security/models/signup_dto.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TelvriSecurity::SignupDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TelvriSecurity::SignupDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] else self.full_name = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'company') self.company = attributes[:'company'] end if attributes.key?(:'password') self.password = attributes[:'password'] else self.password = nil end if attributes.key?(:'confirm_password') self.confirm_password = attributes[:'confirm_password'] else self.confirm_password = nil end end |
Instance Attribute Details
#company ⇒ Object
Company or team name.
25 26 27 |
# File 'lib/telvri_security/models/signup_dto.rb', line 25 def company @company end |
#confirm_password ⇒ Object
Password confirmation.
31 32 33 |
# File 'lib/telvri_security/models/signup_dto.rb', line 31 def confirm_password @confirm_password end |
#email ⇒ Object
Work email used for dashboard access and API key delivery.
22 23 24 |
# File 'lib/telvri_security/models/signup_dto.rb', line 22 def email @email end |
#full_name ⇒ Object
Full name for the developer account.
19 20 21 |
# File 'lib/telvri_security/models/signup_dto.rb', line 19 def full_name @full_name end |
#password ⇒ Object
Account password.
28 29 30 |
# File 'lib/telvri_security/models/signup_dto.rb', line 28 def password @password end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/telvri_security/models/signup_dto.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/telvri_security/models/signup_dto.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/telvri_security/models/signup_dto.rb', line 34 def self.attribute_map { :'full_name' => :'fullName', :'email' => :'email', :'company' => :'company', :'password' => :'password', :'confirm_password' => :'confirmPassword' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/telvri_security/models/signup_dto.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/telvri_security/models/signup_dto.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/telvri_security/models/signup_dto.rb', line 55 def self.openapi_types { :'full_name' => :'String', :'email' => :'String', :'company' => :'String', :'password' => :'String', :'confirm_password' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
211 212 213 214 215 216 217 218 219 |
# File 'lib/telvri_security/models/signup_dto.rb', line 211 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && email == o.email && company == o.company && password == o.password && confirm_password == o.confirm_password end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/telvri_security/models/signup_dto.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/telvri_security/models/signup_dto.rb', line 229 def hash [full_name, email, company, password, confirm_password].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/telvri_security/models/signup_dto.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @full_name.nil? invalid_properties.push('invalid value for "full_name", full_name cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @password.nil? invalid_properties.push('invalid value for "password", password cannot be nil.') end if @password.to_s.length < 8 invalid_properties.push('invalid value for "password", the character length must be greater than or equal to 8.') end if @confirm_password.nil? invalid_properties.push('invalid value for "confirm_password", confirm_password cannot be nil.') end if @confirm_password.to_s.length < 8 invalid_properties.push('invalid value for "confirm_password", the character length must be greater than or equal to 8.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/telvri_security/models/signup_dto.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/telvri_security/models/signup_dto.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @full_name.nil? return false if @email.nil? return false if @password.nil? return false if @password.to_s.length < 8 return false if @confirm_password.nil? return false if @confirm_password.to_s.length < 8 true end |