Class: TelvriSecurity::SimSwapResponseDto
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TelvriSecurity::SimSwapResponseDto
- Defined in:
- lib/telvri_security/models/sim_swap_response_dto.rb
Instance Attribute Summary collapse
-
#last_swapped_at ⇒ Object
ISO-8601 timestamp of the most recent SIM-swap signal.
-
#operator ⇒ Object
Resolved mobile network operator.
-
#phone_number ⇒ Object
Subscriber phone number in E.164 format.
-
#provider ⇒ Object
Resolved mobile network operator or telecom provider (global prefix catalog).
-
#swapped ⇒ Object
Whether the network registry indicates a recent SIM swap.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SimSwapResponseDto
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SimSwapResponseDto
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TelvriSecurity::SimSwapResponseDto` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TelvriSecurity::SimSwapResponseDto`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] else self.phone_number = nil end if attributes.key?(:'swapped') self.swapped = attributes[:'swapped'] else self.swapped = nil end if attributes.key?(:'last_swapped_at') self.last_swapped_at = attributes[:'last_swapped_at'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'operator') self.operator = attributes[:'operator'] else self.operator = nil end end |
Instance Attribute Details
#last_swapped_at ⇒ Object
ISO-8601 timestamp of the most recent SIM-swap signal.
25 26 27 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 25 def last_swapped_at @last_swapped_at end |
#operator ⇒ Object
Resolved mobile network operator. Alias retained for telco domain consumers.
31 32 33 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 31 def operator @operator end |
#phone_number ⇒ Object
Subscriber phone number in E.164 format.
19 20 21 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 19 def phone_number @phone_number end |
#provider ⇒ Object
Resolved mobile network operator or telecom provider (global prefix catalog).
28 29 30 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 28 def provider @provider end |
#swapped ⇒ Object
Whether the network registry indicates a recent SIM swap.
22 23 24 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 22 def swapped @swapped end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 34 def self.attribute_map { :'phone_number' => :'phoneNumber', :'swapped' => :'swapped', :'last_swapped_at' => :'lastSwappedAt', :'provider' => :'provider', :'operator' => :'operator' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 218 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 55 def self.openapi_types { :'phone_number' => :'String', :'swapped' => :'Boolean', :'last_swapped_at' => :'Time', :'provider' => :'String', :'operator' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
193 194 195 196 197 198 199 200 201 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 193 def ==(o) return true if self.equal?(o) self.class == o.class && phone_number == o.phone_number && swapped == o.swapped && last_swapped_at == o.last_swapped_at && provider == o.provider && operator == o.operator end |
#eql?(o) ⇒ Boolean
205 206 207 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 205 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
211 212 213 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 211 def hash [phone_number, swapped, last_swapped_at, provider, operator].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @phone_number.nil? invalid_properties.push('invalid value for "phone_number", phone_number cannot be nil.') end if @swapped.nil? invalid_properties.push('invalid value for "swapped", swapped cannot be nil.') end if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @operator.nil? invalid_properties.push('invalid value for "operator", operator cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 240 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
142 143 144 145 146 147 148 149 |
# File 'lib/telvri_security/models/sim_swap_response_dto.rb', line 142 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @phone_number.nil? return false if @swapped.nil? return false if @provider.nil? return false if @operator.nil? true end |